@@ -21,7 +21,7 @@ class CallChannel(
 
 		try:
 			# HACK Older python-telepathy way
-			telepathy.server.ChannelTypeStreamedMedia.__init__(self, connection, None)
+			telepathy.server.ChannelTypeStreamedMedia.__init__(self, connection, contactHandle)
 			self._requested = props[telepathy.interfaces.CHANNEL_INTERFACE + '.Requested']
 			self._implement_property_get(
 				telepathy.interfaces.CHANNEL_INTERFACE,
@@ -41,9 +41,19 @@ class CallChannel(
 			},
 		)
 
+		# HACK Older python-telepathy doesn't provide this
+		self._immutable_properties = {
+			'ChannelType': telepathy.server.interfaces.CHANNEL_INTERFACE,
+			'TargetHandle': telepathy.server.interfaces.CHANNEL_INTERFACE,
+			'Interfaces': telepathy.server.interfaces.CHANNEL_INTERFACE,
+			'TargetHandleType': telepathy.server.interfaces.CHANNEL_INTERFACE,
+			'TargetID': telepathy.server.interfaces.CHANNEL_INTERFACE,
+			'Requested': telepathy.server.interfaces.CHANNEL_INTERFACE
+		}
+
 		self.GroupFlagsChanged(0, 0)
 		self.MembersChanged(
-			'', [self._conn.GetSetHandle()], [], [], [contactHandle],
+			'', [self._conn.GetSelfHandle()], [], [], [contactHandle],
 			0, telepathy.CHANNEL_GROUP_CHANGE_REASON_NONE
 		)
 
@@ -55,16 +65,8 @@ class CallChannel(
 
 	def get_props(self):
 		# HACK Older python-telepathy doesn't provide this
-		_immutable_properties = {
-			'ChannelType': telepathy.server.interfaces.CHANNEL_INTERFACE,
-			'TargetHandle': telepathy.server.interfaces.CHANNEL_INTERFACE,
-			'Interfaces': telepathy.server.interfaces.CHANNEL_INTERFACE,
-			'TargetHandleType': telepathy.server.interfaces.CHANNEL_INTERFACE,
-			'TargetID': telepathy.server.interfaces.CHANNEL_INTERFACE,
-			'Requested': telepathy.server.interfaces.CHANNEL_INTERFACE
-		}
 		props = dict()
-		for prop, iface in _immutable_properties.items():
+		for prop, iface in self._immutable_properties.items():
 			props[iface + '.' + prop] = \
 				self._prop_getters[iface][prop]()
 		return props
