@@ -24,7 +24,7 @@ class TelepathyChannelManager(object):
 		for channel_type in self._requestable_channel_classes:
 			for chan in self._channels[channel_type].values():
 				try:
-					_moduleLogger.info("Closing %s %s" % (channel_type, chan._object_path))
+					_moduleLogger.debug("Closing %s %s" % (channel_type, chan._object_path))
 					chan.Close()
 				except Exception:
 					_moduleLogger.exception("Shutting down %r" % (chan, ))
@@ -70,6 +70,7 @@ class TelepathyChannelManager(object):
 			self._conn.add_channels([chan], signal=signal)
 		elif hasattr(self._conn, "add_channel"):
 			# HACK Older python-telepathy
+			self._conn.NewChannels([(chan._object_path, chan.get_props())])
 			self._conn.add_channel(chan, handle, suppress_handler)
 		else:
 			raise RuntimeError("Uhh, what just happened with the connection")
@@ -147,7 +148,6 @@ class ChannelManager(TelepathyChannelManager):
 			chan = channel.debug_prompt.DebugPromptChannel(self._conn, self, props, h)
 		else:
 			_moduleLogger.debug('New text channel')
-			_moduleLogger.info('%r %r' % (accountNumber, h.phoneNumber))
 			chan = channel.text.TextChannel(self._conn, self, props, h)
 		return chan
 
